<?php

namespace Drupal\taxonomy_search_admin_form\tests\src\Functionnal;

use Drupal\Tests\BrowserTestBase;
use Drupal\taxonomy\Entity\Vocabulary;
use Drupal\taxonomy\Entity\Term;

/**
 * Functionnal test for taxonomy search form.
 *
 * @group taxonomy_search
 */
class EditFormTest extends BrowserTestBase {

  /**
   * Default theme to use.
   */
  protected $defaultTheme = 'claro';

  /**
   * Required modules.
   *
   * @var array
   */
  protected static $modules = ['taxonomy', 'taxonomy_search_admin_form'];

  /**
   * Admin user.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    
    parent::setUp();
   
    $this->adminUser = $this->drupalCreateUser([
      'administer taxonomy',
      'administer taxonomy search admin form'
    ]);
    
    $this->drupalLogin($this->adminUser);

    if (!Vocabulary::load('tags')) {
      $vocabulary = Vocabulary::create([
        'vid' => 'tags',
        'name' => 'Tags',
      ]);
      $vocabulary->save();
    }

    $term = Term::create([
      'name' => 'Steven Spielberg',
      'vid' => 'tags',
    ]);
    $term->save();

  }

  /**
   * Test form taxonomy search.
   */
  public function testFormSubmission() {

    $this->drupalGet('/admin/taxonomy/search');

    $this->assertSession()->fieldExists('tid');

    $edit = [
      'tid' => 'Steven Spielberg',
    ];
    $this->submitForm($edit, 'Search');

    $this->assertSession()->pageTextContains('Edit term');
  }

}
